@@ -20,7 +20,7 @@ def __get_version() -> Optional[str]:
     return None
 
 __version__ = __get_version() or "0.0.0"
-__cryptonym__ = "preposterous ports"
+__cryptonym__ = "electric orchestra"
 
 # Add the devtools debug() function to builtins if available
 import builtins
@@ -39,7 +39,10 @@ from .events import *
 from .logging import *
 from .pubsub import *
 from .servo import *
-from .types import *
+from .types.api import *
+from .types.core import *
+from .types.settings import *
+from .types.slo import *
 from .utilities import *
 
 # Resolve forward references
