@@ -18,6 +18,7 @@ import typer
 
 import servo
 import servo.api
+import servo.telemetry
 import servo.configuration
 import servo.utilities.key_paths
 import servo.utilities.strings
@@ -31,6 +32,7 @@ class ServoRunner(pydantic.BaseModel, servo.logging.Mixin, servo.api.Mixin):
     _connected: bool = pydantic.PrivateAttr(False)
     _running: bool = pydantic.PrivateAttr(False)
     _main_loop_task: Optional[asyncio.Task] = pydantic.PrivateAttr(None)
+    _diagnostics_loop_task: Optional[asyncio.Task] = pydantic.PrivateAttr(None)
 
     class Config:
         arbitrary_types_allowed = True
@@ -118,12 +120,6 @@ class ServoRunner(pydantic.BaseModel, servo.logging.Mixin, servo.api.Mixin):
         self.logger.success(f"Adjustment completed {summary}")
         return aggregate_description
 
-    @backoff.on_exception(
-        backoff.expo,
-        (httpx.HTTPError, pydantic.ValidationError),
-        max_time=lambda: servo.current_servo().config.settings.backoff.max_time(),
-        max_tries=lambda: servo.current_servo().config.settings.backoff.max_tries(),
-    )
     async def exec_command(self) -> servo.api.Status:
         cmd_response = await self._post_event(servo.api.Events.whats_next, None)
         self.logger.info(f"What's Next? => {cmd_response.command}")
@@ -228,6 +224,9 @@ class ServoRunner(pydantic.BaseModel, servo.logging.Mixin, servo.api.Mixin):
         if self._main_loop_task:
             self._main_loop_task.cancel()
 
+        if self._diagnostics_loop_task:
+            self._diagnostics_loop_task.cancel()
+
         def _reraise_if_necessary(task: asyncio.Task) -> None:
             try:
                 if not task.cancelled():
@@ -240,6 +239,12 @@ class ServoRunner(pydantic.BaseModel, servo.logging.Mixin, servo.api.Mixin):
         self._main_loop_task = asyncio.create_task(self.main_loop(), name=f"main loop for servo {self.optimizer.id}")
         self._main_loop_task.add_done_callback(_reraise_if_necessary)
 
+        if not servo.current_servo().config.no_diagnostics:
+            diagnostics_handler = servo.telemetry.DiagnosticsHandler(self.servo)
+            self._diagnostics_loop_task = asyncio.create_task(diagnostics_handler.diagnostics_check(), name=f"diagnostics for servo {self.optimizer.id}")
+        else:
+            self.logger.info(f"Servo runner initialized with diagnostics polling disabled")
+
     async def run(self, *, poll: bool = True) -> None:
         self._running = True
 
@@ -290,6 +295,7 @@ class ServoRunner(pydantic.BaseModel, servo.logging.Mixin, servo.api.Mixin):
         else:
             self.logger.warning(f"Servo runner initialized with polling disabled -- command loop is not running")
 
+
     async def shutdown(self, *, reason: Optional[str] = None) -> None:
         """Shutdown the running servo."""
         try:
@@ -385,6 +391,7 @@ class AssemblyRunner(pydantic.BaseModel, servo.logging.Mixin):
                 if poll:
                     runner = self._runner_for_servo(servo.current_servo())
                     runner.run_main_loop()
+
             else:
                 self.logger.error(
                     f"unrecognized exception passed to progress exception handler: {error}"
